import re
import secrets
from typing import Optional


MAX_TRIGGER_WORDS = 3
WORD_PATTERN = re.compile(r"(\w+)")


class BrainCell:
    """
    Main thinking mechanism.

    It decides when and what to say.
    """

    def create_reply(self, sentence: str) -> Optional[str]:
        """
        The hardest action to accomplish.

        This brain cell function produces
        thoughtful reply to evrey sentence that
        needs it.

        :param sentence: Sentence that needs a reply.
        :return: actual reply.
        """
        tokens = WORD_PATTERN.findall(sentence)
        if not tokens or len(tokens) > MAX_TRIGGER_WORDS:
            return None
        *_, last_token = tokens
        last_token_parts = last_token.lower().split("да")
        if len(last_token_parts) > 1:
            return f"Пизда{last_token_parts[-1]}."
        return None
